@@ -46,8 +46,6 @@ class PackageKitResource : public AbstractResource
 
         void clearPackageIds() { m_packages.clear(); }
 
-        QMap<PackageKit::Transaction::Info, QStringList> packages() const { return m_packages; }
-
         PackageKitBackend* backend() const;
 
         static QString joinPackages(const QStringList& pkgids, const QString &_sep, const QString &shadowPackageName);
@@ -96,7 +94,19 @@ class PackageKitResource : public AbstractResource
         /** fetches details individually, it's better if done in batch, like for updates */
         virtual void fetchDetails();
 
-        QMap<PackageKit::Transaction::Info, QStringList> m_packages;
+        struct Ids {
+            QVector<QString> archPkgIds;
+            QVector<QString> nonarchPkgIds;
+
+            QString first() const {
+                return !archPkgIds.isEmpty() ? archPkgIds.first() : nonarchPkgIds.first();
+            }
+
+            bool isEmpty() const {
+                return archPkgIds.isEmpty() && nonarchPkgIds.isEmpty();
+            }
+        };
+        QMap<PackageKit::Transaction::Info, Ids> m_packages;
         const QString m_summary;
         const QString m_name;
         int m_dependenciesCount = -1;
